package com.drinkertea.test2smack;

import android.app.NotificationChannel;
import android.app.NotificationManager;
import android.app.PendingIntent;
import android.app.Service;
import android.content.Intent;
import android.os.Build;
import android.os.IBinder;

import androidx.core.app.NotificationCompat;
import androidx.core.app.NotificationManagerCompat;
import androidx.core.app.TaskStackBuilder;

import org.jivesoftware.smack.AbstractXMPPConnection;
import org.jivesoftware.smack.chat2.Chat;
import org.jivesoftware.smack.chat2.ChatManager;
import org.jivesoftware.smack.chat2.IncomingChatMessageListener;
import org.jivesoftware.smack.packet.Message;
import org.jivesoftware.smack.tcp.XMPPTCPConnection;
import org.jivesoftware.smack.tcp.XMPPTCPConnectionConfiguration;
import org.jxmpp.jid.EntityBareJid;
import org.jxmpp.jid.impl.JidCreate;
import org.jxmpp.stringprep.XmppStringprepException;


public class NotificationService extends Service {

    public static boolean serverIsWorked = false;
    NotificationCompat.Builder builder;
    @Override
    public int onStartCommand(Intent intent, int flags, int startId) {
        try {
            if(!serverIsWorked){
                new Thread(new Runnable() {
                    @Override
                    public void run() {
                        try {
                            task();
                        } catch (Exception e) {
                            e.printStackTrace();
                        }
                    }
                }).start();
                serverIsWorked = true;
                builder = new NotificationCompat.Builder(this, "My channel")
                        .setContentText("Notification server was running!")
                        .setContentTitle("Assist chat")
                        .setSmallIcon(R.mipmap.ic_launcher_round);
                startForeground(1001, builder.build());
            }

        } catch (Exception e) {
            e.printStackTrace();
        }
        return super.onStartCommand(intent, flags, startId);
    }

    @Override
    public void onCreate() {
        super.onCreate();
        if(Build.VERSION.SDK_INT >= Build.VERSION_CODES.O){
            NotificationChannel channel = new NotificationChannel("My channel", "My notification", NotificationManager.IMPORTANCE_DEFAULT);
            NotificationManager manager = getSystemService(NotificationManager.class);
            manager.createNotificationChannel(channel);
        }
        System.out.println("Server started!");
    }

    @Override
    public IBinder onBind(Intent intent) {
        return null;
    }

    private void task() throws Exception{
        XMPPClass.chatManager.addIncomingListener(new IncomingChatMessageListener() {
            @Override
            public void newIncomingMessage(EntityBareJid from, Message message, Chat chat) {
                System.out.println("New message from:" + from + ": " + message.getBody());
                try {
                    createNotificationChannel(from, message.getBody());
                }catch (Exception ex){
                    System.out.println(ex.getMessage());
                }
            }
        });
    }
    private void createNotificationChannel(EntityBareJid from, String message) {
        try {
            XMPPClass.chatJid = JidCreate.entityBareFrom(from);
        } catch (XmppStringprepException e) {
            e.printStackTrace();
        }
        Intent resultIntent = new Intent(this, MainActivity.class);
        TaskStackBuilder stackBuilder = TaskStackBuilder.create(this);
        stackBuilder.addNextIntentWithParentStack(resultIntent);
        PendingIntent resultPendingIntent =
                stackBuilder.getPendingIntent(0,
                        PendingIntent.FLAG_UPDATE_CURRENT | PendingIntent.FLAG_IMMUTABLE);

        NotificationCompat.Builder builder = new NotificationCompat.Builder(NotificationService.this, "My channel");
        builder.setContentTitle(from.asBareJid().toString());
        builder.setContentText(message);
        builder.setSmallIcon(R.mipmap.ic_launcher);
        builder.setAutoCancel(true);
        builder.setContentIntent(resultPendingIntent);

        startForeground(1001, builder.build());
    }

    @Override
    public void onDestroy() {
        super.onDestroy();
        serverIsWorked = false;
        System.out.println("Server destroy!");
    }
}
